# Hi Googlers! If you're looking in here for patches, nifty.
# You (and everyone else) are welcome to use any of my Chromium patches under the terms of the GPLv2 or later.
# You (and everyone else) are welcome to use any of my V8-specific patches under the terms of the BSD license.
# You (and everyone else) may NOT use my patches under any other terms.
# I hate to be a party-pooper here, but I really don't want to help Google make a proprietary browser.
# There are enough of those already.
# All copyrightable work in these spec files and patches is Copyright 2010 Tom Callaway

# For the 1.2 branch, we use 0s here
# For 1.3+, we use the three digit versions


%define libname %mklibname v8
%define develname %mklibname v8 -d



%ifarch x86_64
%define archrel x64.release
%endif

%ifarch %ix86
%define archrel ia32.release
%endif

%ifarch %arm
%define archrel armeabi=hard vfp3=on
%endif


%define soname_ver 3.12.11

%global somajor 3
%global sominor 12
%global sobuild 11
%global sover %{somajor}.%{sominor}.%{sobuild}
%{!?python_sitelib: %global python_sitelib %(%{__python} \
    -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

Name:	    v8
Version:    %{somajor}.%{sominor}.%{sobuild}
Release:    1
Summary:    JavaScript Engine
Group:      System/Libraries
License:    BSD
URL:        http://code.google.com/p/v8
Source0:    http://commondatastorage.googleapis.com/chromium-browser-official/%{name}-%{somajor}.%{sominor}.%{sobuild}.tar.bz2
ExclusiveArch:    %{ix86} x86_64 arm
BuildRequires:    scons
BuildRequires:    readline-devel
BuildRequires:    icu-devel >= 49
Obsoletes:		  v8 < %{version}-%{release}

%description
V8 is Google's open source JavaScript engine. V8 is written in C++ and is used 
in Google Chrome, the open source browser from Google. V8 implements ECMAScript 
as specified in ECMA-262, 3rd edition.

%files
%doc AUTHORS ChangeLog LICENSE
%{_bindir}/d8


%package -n %libname
Group:      System/Libraries
Summary:    libraries for v8
Requires:   %{name} = %{version}-%{release}

%description -n %libname
Library for V8 Google's open source JavaScript engine.


%files -n %libname
%{_libdir}/*.so.*

#--------------------------------------------------------------------

%package -n %develname
Group:      System/Libraries 
Summary:    Development headers and libraries for v8
Requires:   %{libname} = %{version}-%{release}
Requires:   %{name} = %{version}-%{release}
Provides:   %{name}-devel = %{version}-%{release}
Obsoletes:	%{name}-devel < %{version}-%{release}

%description -n %develname
Development headers and libraries for v8.

%files -n %develname
%{_includedir}/*.h
%{_includedir}/v8/extensions/
%{_libdir}/*.so
%{python_sitelib}/j*.py*

#--------------------------------------------------------------------

%prep
%setup -q -n %{name}-%{version}

# clear spurious executable bits
find . \( -name \*.cc -o -name \*.h -o -name \*.py \) -a -executable \
  |while read FILE ; do
    echo $FILE
    chmod -x $FILE
  done


%build
	
	
make -j3 GYP_GENERATORS=make  V=1 werror=no \
	library=shared \
	snapshots=on \
	soname_version=%{sover} \
	visibility=default \
	%{archrel}	

%install
mkdir -p %{buildroot}%{_includedir}
mkdir -p %{buildroot}%{_libdir}
install -p include/*.h %{buildroot}%{_includedir}
install -p out/%{archrel}/lib.target//libv8.so.%{sover} %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_bindir}
install -p -m0755 out/%{archrel}/d8 %{buildroot}%{_bindir}

chmod -x %{buildroot}%{_includedir}/v8*.h

mkdir -p %{buildroot}%{_includedir}/v8/extensions/experimental/
install -p src/extensions/*.h %{buildroot}%{_includedir}/v8/extensions/

chmod -x %{buildroot}%{_includedir}/v8/extensions/*.h

pushd %{buildroot}%{_libdir}
ln -sf libv8.so.%{sover} libv8.so
ln -sf libv8.so.%{sover} libv8.so.%{somajor}
ln -sf libv8.so.%{sover} libv8.so.%{somajor}.%{sominor}
popd






# install Python JS minifier scripts for nodejs
install -d %{buildroot}%{python_sitelib}
install -p -m0744 tools/jsmin.py %{buildroot}%{python_sitelib}/
chmod -R -x %{buildroot}%{python_sitelib}/*.py*


%changelog
* Thu Jul 19 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.12.11-1
+ Revision: 810185
- version update  3.12.11

* Mon Jul 16 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.11.10.14-1
+ Revision: 809821
- version update 3.11.10.14

* Mon Jun 25 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.10.8.19-1
+ Revision: 806783
- version update 3.10.8.19

* Thu Jun 21 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.10.8.18-1
+ Revision: 806592
- version update 3.10.8.18

* Thu Jun 14 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.10.8.16-1
+ Revision: 805658
- version update 3.10.8.16

* Mon Jun 11 2012 Lev Givon <lev@mandriva.org> 3.10.8.15-1
+ Revision: 804377
- Update to 3.10.8.15.

* Sun Jun 10 2012 Lev Givon <lev@mandriva.org> 3.10.8.13-3
+ Revision: 804368
- Don't self-obsolete v8 package.
- Obsolete old v8-devel package.

* Thu Jun 07 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.10.8.13-1
+ Revision: 803094
- version update 3.10.8.13

* Thu May 10 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.9.24.21-1
+ Revision: 797886
- version update 8-3.9.24.21

* Thu May 03 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.9.24.17-1
+ Revision: 795288
- version update 3.9.24.17

* Sat Apr 28 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.9.24.16-7
+ Revision: 794221
- test build

* Sat Apr 28 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.9.24.16-6
+ Revision: 794207
- name not found fix

* Fri Apr 27 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.9.24.16-5
+ Revision: 794116
- rel up
- requires section libname

* Fri Apr 27 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.9.24.16-4
+ Revision: 794072
- rel up
- archrel macro in install section
- macro separated
- rel up
- arch ix86 instead of macro %
- broken define section
- broken link fix
- version update 3.9.24.16
- version update 3.9.24.16

* Wed Apr 18 2012 Lev Givon <lev@mandriva.org> 3.8.9.16-3
+ Revision: 791808
- Fix lib/devel package interdependencies.

* Sat Apr 07 2012 Bernhard Rosenkraenzer <bero@bero.eu> 3.8.9.16-2
+ Revision: 789780
- Rebuild for icu 49.1

* Tue Mar 27 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.8.9.16-1
+ Revision: 787414
- version update 3.8.9.16

* Mon Mar 19 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.8.9.15-2
+ Revision: 785523
- version update 3.8.9.15

* Wed Feb 22 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.8.9.8-2
+ Revision: 779210
- release bump
- develname and libname pacakge separated

* Wed Feb 22 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.8.9.8-1
+ Revision: 779182
- version update 3.8.9.8

* Thu Feb 16 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.8.9.6-1
+ Revision: 775293
- imported package v8

